Main functions
==============

.. currentmodule:: nngt

.. autofunction:: generate

.. autofunction:: get_config

.. autofunction:: load_from_file

.. autofunction:: num_mpi_processes

.. autofunction:: on_master_process

.. autofunction:: save_to_file

.. autofunction:: seed

.. autofunction:: set_config

.. autofunction:: use_library
